@@ -7,6 +7,7 @@
 #include "dolphincontextmenu.h"
 
 #include "dolphin_contextmenusettings.h"
+#include "dolphin_generalsettings.h"
 #include "dolphinmainwindow.h"
 #include "dolphinnewfilemenu.h"
 #include "dolphinplacesmodelsingleton.h"
@@ -125,6 +126,18 @@ void DolphinContextMenu::addTrashContextMenu()
     });
     emptyTrashAction->setEnabled(!Trash::isEmpty());
 
+    // Insert 'Sort By' and 'View Mode'
+    if (ContextMenuSettings::showSortBy() || ContextMenuSettings::showViewMode()) {
+        addSeparator();
+    }
+    if (ContextMenuSettings::showSortBy()) {
+        addAction(m_mainWindow->actionCollection()->action(QStringLiteral("sort")));
+    }
+    if (ContextMenuSettings::showViewMode()) {
+        addAction(m_mainWindow->actionCollection()->action(QStringLiteral("view_mode")));
+    }
+
+    addSeparator();
     QAction *propertiesAction = m_mainWindow->actionCollection()->action(QStringLiteral("properties"));
     addAction(propertiesAction);
 }
@@ -149,6 +162,11 @@ void DolphinContextMenu::addTrashItemContextMenu()
     QAction *deleteAction = m_mainWindow->actionCollection()->action(KStandardAction::name(KStandardAction::DeleteFile));
     addAction(deleteAction);
 
+    addSeparator();
+    addAction(m_mainWindow->actionCollection()->action(KStandardAction::name(KStandardAction::Cut)));
+    addAction(m_mainWindow->actionCollection()->action(KStandardAction::name(KStandardAction::Copy)));
+
+    addSeparator();
     QAction *propertiesAction = m_mainWindow->actionCollection()->action(QStringLiteral("properties"));
     addAction(propertiesAction);
 }
@@ -332,7 +350,7 @@ void DolphinContextMenu::insertDefaultItemActions(const KFileItemListProperties
     addAction(collection->action(KStandardAction::name(KStandardAction::Cut)));
     addAction(collection->action(KStandardAction::name(KStandardAction::Copy)));
     if (ContextMenuSettings::showCopyLocation()) {
-        QAction *copyPathAction = collection->action(QString("copy_location"));
+        QAction *copyPathAction = collection->action(QStringLiteral("copy_location"));
         copyPathAction->setEnabled(m_selectedItems.size() == 1);
         addAction(copyPathAction);
     }
@@ -440,7 +458,9 @@ void DolphinContextMenu::addOpenWithActions()
     m_fileItemActions->insertOpenWithActionsTo(nullptr, this, QStringList{qApp->desktopFileName()});
 
     // For a single file, hint in "Open with" menu that middle-clicking would open it in the secondary app.
-    if (m_selectedItems.count() == 1 && !m_fileInfo.isDir()) {
+    // (Unless middle-clicking would open it as a folder in a new tab (e.g. archives).)
+    const QUrl &url = DolphinView::openItemAsFolderUrl(m_fileInfo, GeneralSettings::browseThroughArchives());
+    if (m_selectedItems.count() == 1 && url.isEmpty()) {
         if (QAction *openWithSubMenu = findChild<QAction *>(QStringLiteral("openWith_submenu"))) {
             Q_ASSERT(openWithSubMenu->menu());
             Q_ASSERT(!openWithSubMenu->menu()->isEmpty());
