@@ -1,6 +1,6 @@
 /*
  * SPDX-FileCopyrightText: 2014 Emmanuel Pescosta <emmanuelpescosta099@gmail.com>
- * SPDX-FileCopyrightText: 2020 Felix Ernst <fe.a.ernst@gmail.com>
+ * SPDX-FileCopyrightText: 2020 Felix Ernst <felixernst@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -164,6 +164,15 @@ DolphinViewContainer *DolphinTabPage::activeViewContainer() const
     return m_primaryViewActive ? m_primaryViewContainer : m_secondaryViewContainer;
 }
 
+DolphinViewContainer *DolphinTabPage::inactiveViewContainer() const
+{
+    if (!splitViewEnabled()) {
+        return nullptr;
+    }
+
+    return primaryViewActive() ? secondaryViewContainer() : primaryViewContainer();
+}
+
 KFileItemList DolphinTabPage::selectedItems() const
 {
     KFileItemList items = m_primaryViewContainer->view()->selectedItems();
@@ -527,3 +536,5 @@ QSplitterHandle *DolphinTabPageSplitter::createHandle()
 {
     return new DolphinTabPageSplitterHandle(orientation(), this);
 }
+
+#include "moc_dolphintabpage.cpp"
