@@ -14,14 +14,20 @@
 
 #include <KFileItem>
 #include <KIO/Job>
+#include <KMessageWidget>
 #include <KUrlNavigator>
 
 #include <QElapsedTimer>
 #include <QPushButton>
 #include <QWidget>
 
+#include <initializer_list>
+
+namespace Admin
+{
+class Bar;
+}
 class FilterBar;
-class KMessageWidget;
 class QAction;
 class QGridLayout;
 class QUrl;
@@ -49,8 +55,6 @@ class DolphinViewContainer : public QWidget
     Q_OBJECT
 
 public:
-    enum MessageType { Information, Warning, Error };
-
     DolphinViewContainer(const QUrl &url, QWidget *parent);
     ~DolphinViewContainer() override;
 
@@ -147,10 +151,10 @@ public:
     bool isSelectionModeEnabled() const;
 
     /**
-     * Shows the message \msg with the given type non-modal above
-     * the view-content.
+     * Shows the message \message with the given type \messageType non-modal above the view-content.
+     * \buttonActions defines actions which the user can trigger as a response to this message. They are presented as buttons below the \message.
      */
-    void showMessage(const QString &msg, MessageType type);
+    void showMessage(const QString &message, KMessageWidget::MessageType messageType, std::initializer_list<QAction *> buttonActions = {});
 
     /**
      * Refreshes the view container to get synchronized with the (updated) Dolphin settings.
@@ -279,10 +283,6 @@ private Q_SLOTS:
      */
     void updateStatusBar();
 
-    void updateDirectoryLoadingProgress(int percent);
-
-    void updateDirectorySortingProgress(int percent);
-
     /**
      * Updates the statusbar to show an undetermined progress with the correct
      * context information whether a searching or a directory loading is done.
@@ -388,9 +388,14 @@ private Q_SLOTS:
     void slotStatusBarZoomLevelChanged(int zoomLevel);
 
     /**
-     * Slot that calls showMessage(msg, Error).
+     * Creates and shows an error message based on \p message and \p kioErrorCode.
      */
-    void showErrorMessage(const QString &msg);
+    void slotErrorMessageFromView(const QString &message, const int kioErrorCode);
+
+    /**
+     * Slot that calls showMessage(message, KMessageWidget::Error).
+     */
+    void showErrorMessage(const QString &message);
 
     /**
      * Is invoked when a KFilePlacesModel has been changed
@@ -447,6 +452,11 @@ private:
     DolphinSearchBox *m_searchBox;
     bool m_searchModeEnabled;
 
+    /// A bar shown at the top of the view to signify that the view is currently viewed and acted on with elevated privileges.
+    Admin::Bar *m_adminBar;
+    /// An action to switch to the admin protocol. This variable will always be nullptr unless kio-admin was installed. @see Admin::WorkerIntegration.
+    QAction *m_authorizeToEnterFolderAction;
+
     KMessageWidget *m_messageWidget;
 
     /// A bar shown at the top of the view to signify that selection mode is currently active.
